@@ -30,9 +30,9 @@ impl NQueens {
     /// Return `None` if no solution after.
     pub fn solve_next<S>(state: S) -> Option<NQueensBoard>
     where
-        S: Iterator<Item = usize>,
+        S: Into<NQueensBoard>,
     {
-        let mut out = NQueensBoard::new(state);
+        let mut out = state.into();
         match out.next_solution() {
             true => Some(out),
             false => None,
